# Utils

General utilities complimenting and expanding on standard python.

## Setup & Install

https://pypi.org/project/utils-nuuuwan/#history

```
pip install utils-nuuuwan
```

## Version History (1.2.x)


### 1.2.7  (CURRENT RELEASE)
* fix TSVFile encoding BUG

### 1.2.6 
* WWW: Updated local_path for download

### 1.2.5
* Fix windows-specific BUGS

### 1.2.4 
* Removed Dependency on WGET from WWW. Updated local file logic. 

### 1.2.3 
* PDFFile
* Added mkdir to Directory
* lint errors
* Make WWW more like a folder

### 1.2.2 
* Fix Multiple Twitter API Creation BUG
* refactoring, reducing complexity, test coverage

### 1.2.1 
* Added FiledVariable  
* Added File.delete

### 1.2.0 
* Deprecated cache, GoogleMaps #BREAKING
* Major updates to Twitter 

* Various refactoring 
